## Description

<!-- Brief description of the changes in this PR -->

## Type of Change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)

## Checklist

- [ ] My code follows the project's code style
- [ ] I have added tests that prove my fix is effective or my feature works
- [ ] All new and existing tests pass (`pytest`)
- [ ] I have run `ruff check` and `ruff format --check` with no errors
- [ ] I have run `mypy src/` with no errors
- [ ] I have updated documentation as needed
- [ ] My commits include a `Signed-off-by` line (DCO)

## Related Issues

<!-- Link any related issues: Fixes #123, Relates to #456 -->
